@@ -822,7 +822,7 @@ class AWSpider:
         self.peer_uuids.sort()
         
 #        print self.peers 
-        logger.debug( "Peers updated to: %s" % self.peer_uuids )
+        logger.debug( "Peers updated to: %s" % self.peers )
         
         # Go through the peers and reorganize the group.
         pass
